# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/processing/processing.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.mdb import mdb_pb2 as yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2
from yamcs.protobuf.pvalue import pvalue_pb2 as yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/processing/processing.proto',
  package='yamcs.protobuf.processing',
  syntax='proto2',
  serialized_options=b'\n\022org.yamcs.protobufB\017ProcessingProtoP\001',
  serialized_pb=b'\n*yamcs/protobuf/processing/processing.proto\x12\x19yamcs.protobuf.processing\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1byamcs/api/annotations.proto\x1a\x1cyamcs/protobuf/mdb/mdb.proto\x1a\"yamcs/protobuf/pvalue/pvalue.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x1a\x1ayamcs/protobuf/yamcs.proto\"+\n\x1aListProcessorTypesResponse\x12\r\n\x05types\x18\x01 \x03(\t\")\n\x15ListProcessorsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"[\n\x16ListProcessorsResponse\x12\x41\n\nprocessors\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.yamcsManagement.ProcessorInfo\"C\n\x1cSubscribeTMStatisticsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"A\n\x1aSubscribeProcessorsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"\xc3\x02\n\x1aSubscribeParametersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12)\n\x02id\x18\x03 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x16\n\x0e\x61\x62ortOnInvalid\x18\x04 \x01(\x08\x12\x1a\n\x12updateOnExpiration\x18\x05 \x01(\x08\x12\x15\n\rsendFromCache\x18\x06 \x01(\x08\x12L\n\x06\x61\x63tion\x18\x07 \x01(\x0e\x32<.yamcs.protobuf.processing.SubscribeParametersRequest.Action\x12\x10\n\x08maxBytes\x18\x08 \x01(\x05\"*\n\x06\x41\x63tion\x12\x0b\n\x07REPLACE\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\"\xce\x03\n\x17SubscribeParametersData\x12P\n\x07mapping\x18\x01 \x03(\x0b\x32?.yamcs.protobuf.processing.SubscribeParametersData.MappingEntry\x12J\n\x04info\x18\x04 \x03(\x0b\x32<.yamcs.protobuf.processing.SubscribeParametersData.InfoEntry\x12.\n\x07invalid\x18\x02 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x35\n\x06values\x18\x03 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x1aM\n\x0cMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId:\x02\x38\x01\x1a_\n\tInfoEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x41\n\x05value\x18\x02 \x01(\x0b\x32\x32.yamcs.protobuf.processing.SubscribedParameterInfo:\x02\x38\x01\"\xd9\x01\n\x17SubscribedParameterInfo\x12\x11\n\tparameter\x18\x01 \x01(\t\x12\r\n\x05units\x18\x02 \x01(\t\x12\x36\n\ndataSource\x18\x03 \x01(\x0e\x32\".yamcs.protobuf.mdb.DataSourceType\x12\x31\n\nenumValues\x18\x04 \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumValue\x12\x31\n\nenumRanges\x18\x05 \x03(\x0b\x32\x1d.yamcs.protobuf.mdb.EnumRange\":\n\x13GetProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"=\n\x16\x44\x65leteProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"j\n\x16\x43reateProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\npersistent\x18\x04 \x01(\x08\x12\x0c\n\x04type\x18\x05 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x06 \x01(\t\"\xe6\x01\n\x14\x45\x64itProcessorRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12(\n\x04seek\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05speed\x18\x05 \x01(\t\x12)\n\x05start\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04loop\x18\x08 \x01(\x08\"q\n\x18GetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tfromCache\x18\x04 \x01(\x08\x12\x0f\n\x07timeout\x18\x05 \x01(\x04\"\xba\x01\n\x18SetParameterValueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12$\n\x05value\x18\x04 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x32\n\x0egenerationTime\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\texpiresIn\x18\x06 \x01(\x04\"\x94\x01\n\x1e\x42\x61tchGetParameterValuesRequest\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x11\n\tprocessor\x18\x05 \x01(\t\x12)\n\x02id\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x11\n\tfromCache\x18\x02 \x01(\x08\x12\x0f\n\x07timeout\x18\x03 \x01(\x04\"W\n\x1f\x42\x61tchGetParameterValuesResponse\x12\x34\n\x05value\x18\x01 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\"\xdf\x02\n\x1e\x42\x61tchSetParameterValuesRequest\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x11\n\tprocessor\x18\x03 \x01(\t\x12\x63\n\x07request\x18\x01 \x03(\x0b\x32R.yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest\x1a\xb2\x01\n\x18SetParameterValueRequest\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\x12\x32\n\x0egenerationTime\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\texpiresIn\x18\x04 \x01(\x04\"N\n\x19GetAlgorithmStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"T\n\x1fSubscribeAlgorithmStatusRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"M\n\x18GetAlgorithmTraceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"]\n\x19\x45\x64itAlgorithmTraceRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\"\xe3\x01\n\x0f\x41lgorithmStatus\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\x14\n\x0ctraceEnabled\x18\x02 \x01(\x08\x12\x10\n\x08runCount\x18\x03 \x01(\r\x12+\n\x07lastRun\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nerrorCount\x18\x05 \x01(\r\x12\x14\n\x0c\x65rrorMessage\x18\x06 \x01(\t\x12-\n\terrorTime\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nexecTimeNs\x18\x08 \x01(\x04\"\x8d\x03\n\x0e\x41lgorithmTrace\x12;\n\x04runs\x18\x01 \x03(\x0b\x32-.yamcs.protobuf.processing.AlgorithmTrace.Run\x12;\n\x04logs\x18\x02 \x03(\x0b\x32-.yamcs.protobuf.processing.AlgorithmTrace.Log\x1a\xc2\x01\n\x03Run\x12(\n\x04time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x06inputs\x18\x02 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12\x36\n\x07outputs\x18\x03 \x03(\x0b\x32%.yamcs.protobuf.pvalue.ParameterValue\x12\x13\n\x0breturnValue\x18\x04 \x01(\t\x12\r\n\x05\x65rror\x18\x05 \x01(\t\x1a<\n\x03Log\x12(\n\x04time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0b\n\x03msg\x18\x03 \x01(\t2\x8b\x16\n\rProcessingApi\x12\x7f\n\x12ListProcessorTypes\x12\x16.google.protobuf.Empty\x1a\x35.yamcs.protobuf.processing.ListProcessorTypesResponse\"\x1a\x8a\x92\x03\x16\n\x14/api/processor-types\x12\x8c\x01\n\x0eListProcessors\x12\x30.yamcs.protobuf.processing.ListProcessorsRequest\x1a\x31.yamcs.protobuf.processing.ListProcessorsResponse\"\x15\x8a\x92\x03\x11\n\x0f/api/processors\x12\x9b\x01\n\x0cGetProcessor\x12..yamcs.protobuf.processing.GetProcessorRequest\x1a-.yamcs.protobuf.yamcsManagement.ProcessorInfo\",\x8a\x92\x03(\n&/api/processors/{instance}/{processor}\x12\x8a\x01\n\x0f\x44\x65leteProcessor\x12\x31.yamcs.protobuf.processing.DeleteProcessorRequest\x1a\x16.google.protobuf.Empty\",\x8a\x92\x03(\"&/api/processors/{instance}/{processor}\x12\x89\x01\n\rEditProcessor\x12/.yamcs.protobuf.processing.EditProcessorRequest\x1a\x16.google.protobuf.Empty\"/\x8a\x92\x03+*&/api/processors/{instance}/{processor}:\x01*\x12v\n\x0f\x43reateProcessor\x12\x31.yamcs.protobuf.processing.CreateProcessorRequest\x1a\x16.google.protobuf.Empty\"\x18\x8a\x92\x03\x14\x1a\x0f/api/processors:\x01*\x12\xb0\x01\n\x11GetParameterValue\x12\x33.yamcs.protobuf.processing.GetParameterValueRequest\x1a%.yamcs.protobuf.pvalue.ParameterValue\"?\x8a\x92\x03;\n9/api/processors/{instance}/{processor}/parameters/{name*}\x12\xee\x01\n\x11SetParameterValue\x12\x33.yamcs.protobuf.processing.SetParameterValueRequest\x1a\x16.google.protobuf.Empty\"\x8b\x01\x8a\x92\x03\x86\x01\x12\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05valueZB\x1a\x39/api/processors/{instance}/{processor}/parameters/{name*}:\x05value\x12\xd5\x01\n\x17\x42\x61tchGetParameterValues\x12\x39.yamcs.protobuf.processing.BatchGetParameterValuesRequest\x1a:.yamcs.protobuf.processing.BatchGetParameterValuesResponse\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchGet:\x01*\x12\xb1\x01\n\x17\x42\x61tchSetParameterValues\x12\x39.yamcs.protobuf.processing.BatchSetParameterValuesRequest\x1a\x16.google.protobuf.Empty\"C\x8a\x92\x03?\x1a:/api/processors/{instance}/{processor}/parameters:batchSet:\x01*\x12\x8d\x01\n\x15SubscribeTMStatistics\x12\x37.yamcs.protobuf.processing.SubscribeTMStatisticsRequest\x1a*.yamcs.protobuf.yamcsManagement.Statistics\"\r\xda\x92\x03\t\n\x07tmstats0\x01\x12\x96\x01\n\x13SubscribeParameters\x12\x35.yamcs.protobuf.processing.SubscribeParametersRequest\x1a\x32.yamcs.protobuf.processing.SubscribeParametersData\"\x10\xda\x92\x03\x0c\n\nparameters(\x01\x30\x01\x12\x8f\x01\n\x13SubscribeProcessors\x12\x35.yamcs.protobuf.processing.SubscribeProcessorsRequest\x1a-.yamcs.protobuf.yamcsManagement.ProcessorInfo\"\x10\xda\x92\x03\x0c\n\nprocessors0\x01\x12\xbe\x01\n\x12GetAlgorithmStatus\x12\x34.yamcs.protobuf.processing.GetAlgorithmStatusRequest\x1a*.yamcs.protobuf.processing.AlgorithmStatus\"F\x8a\x92\x03\x42\n@/api/processors/{instance}/{processor}/algorithms/{name*}/status\x12\x9c\x01\n\x18SubscribeAlgorithmStatus\x12:.yamcs.protobuf.processing.SubscribeAlgorithmStatusRequest\x1a*.yamcs.protobuf.processing.AlgorithmStatus\"\x16\xda\x92\x03\x12\n\x10\x61lgorithm-status0\x01\x12\xba\x01\n\x11GetAlgorithmTrace\x12\x33.yamcs.protobuf.processing.GetAlgorithmTraceRequest\x1a).yamcs.protobuf.processing.AlgorithmTrace\"E\x8a\x92\x03\x41\n?/api/processors/{instance}/{processor}/algorithms/{name*}/trace\x12\xac\x01\n\x12\x45\x64itAlgorithmTrace\x12\x34.yamcs.protobuf.processing.EditAlgorithmTraceRequest\x1a\x16.google.protobuf.Empty\"H\x8a\x92\x03\x44*?/api/processors/{instance}/{processor}/algorithms/{name*}/trace:\x01*\x1a\x04\xd0\x80\x01\x01\x42\'\n\x12org.yamcs.protobufB\x0fProcessingProtoP\x01'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,])



_SUBSCRIBEPARAMETERSREQUEST_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='yamcs.protobuf.processing.SubscribeParametersRequest.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLACE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ADD', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REMOVE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=911,
  serialized_end=953,
)
_sym_db.RegisterEnumDescriptor(_SUBSCRIBEPARAMETERSREQUEST_ACTION)


_LISTPROCESSORTYPESRESPONSE = _descriptor.Descriptor(
  name='ListProcessorTypesResponse',
  full_name='yamcs.protobuf.processing.ListProcessorTypesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='types', full_name='yamcs.protobuf.processing.ListProcessorTypesResponse.types', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=355,
)


_LISTPROCESSORSREQUEST = _descriptor.Descriptor(
  name='ListProcessorsRequest',
  full_name='yamcs.protobuf.processing.ListProcessorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.ListProcessorsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=398,
)


_LISTPROCESSORSRESPONSE = _descriptor.Descriptor(
  name='ListProcessorsResponse',
  full_name='yamcs.protobuf.processing.ListProcessorsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='processors', full_name='yamcs.protobuf.processing.ListProcessorsResponse.processors', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=400,
  serialized_end=491,
)


_SUBSCRIBETMSTATISTICSREQUEST = _descriptor.Descriptor(
  name='SubscribeTMStatisticsRequest',
  full_name='yamcs.protobuf.processing.SubscribeTMStatisticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SubscribeTMStatisticsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SubscribeTMStatisticsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=493,
  serialized_end=560,
)


_SUBSCRIBEPROCESSORSREQUEST = _descriptor.Descriptor(
  name='SubscribeProcessorsRequest',
  full_name='yamcs.protobuf.processing.SubscribeProcessorsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SubscribeProcessorsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SubscribeProcessorsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=562,
  serialized_end=627,
)


_SUBSCRIBEPARAMETERSREQUEST = _descriptor.Descriptor(
  name='SubscribeParametersRequest',
  full_name='yamcs.protobuf.processing.SubscribeParametersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.id', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='abortOnInvalid', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.abortOnInvalid', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='updateOnExpiration', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.updateOnExpiration', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sendFromCache', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.sendFromCache', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.action', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxBytes', full_name='yamcs.protobuf.processing.SubscribeParametersRequest.maxBytes', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SUBSCRIBEPARAMETERSREQUEST_ACTION,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=630,
  serialized_end=953,
)


_SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY = _descriptor.Descriptor(
  name='MappingEntry',
  full_name='yamcs.protobuf.processing.SubscribeParametersData.MappingEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.processing.SubscribeParametersData.MappingEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.SubscribeParametersData.MappingEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1244,
  serialized_end=1321,
)

_SUBSCRIBEPARAMETERSDATA_INFOENTRY = _descriptor.Descriptor(
  name='InfoEntry',
  full_name='yamcs.protobuf.processing.SubscribeParametersData.InfoEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.processing.SubscribeParametersData.InfoEntry.key', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.SubscribeParametersData.InfoEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1323,
  serialized_end=1418,
)

_SUBSCRIBEPARAMETERSDATA = _descriptor.Descriptor(
  name='SubscribeParametersData',
  full_name='yamcs.protobuf.processing.SubscribeParametersData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mapping', full_name='yamcs.protobuf.processing.SubscribeParametersData.mapping', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='info', full_name='yamcs.protobuf.processing.SubscribeParametersData.info', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invalid', full_name='yamcs.protobuf.processing.SubscribeParametersData.invalid', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='yamcs.protobuf.processing.SubscribeParametersData.values', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY, _SUBSCRIBEPARAMETERSDATA_INFOENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=956,
  serialized_end=1418,
)


_SUBSCRIBEDPARAMETERINFO = _descriptor.Descriptor(
  name='SubscribedParameterInfo',
  full_name='yamcs.protobuf.processing.SubscribedParameterInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='parameter', full_name='yamcs.protobuf.processing.SubscribedParameterInfo.parameter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='units', full_name='yamcs.protobuf.processing.SubscribedParameterInfo.units', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataSource', full_name='yamcs.protobuf.processing.SubscribedParameterInfo.dataSource', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValues', full_name='yamcs.protobuf.processing.SubscribedParameterInfo.enumValues', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumRanges', full_name='yamcs.protobuf.processing.SubscribedParameterInfo.enumRanges', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1421,
  serialized_end=1638,
)


_GETPROCESSORREQUEST = _descriptor.Descriptor(
  name='GetProcessorRequest',
  full_name='yamcs.protobuf.processing.GetProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1640,
  serialized_end=1698,
)


_DELETEPROCESSORREQUEST = _descriptor.Descriptor(
  name='DeleteProcessorRequest',
  full_name='yamcs.protobuf.processing.DeleteProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.DeleteProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.DeleteProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1700,
  serialized_end=1761,
)


_CREATEPROCESSORREQUEST = _descriptor.Descriptor(
  name='CreateProcessorRequest',
  full_name='yamcs.protobuf.processing.CreateProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.CreateProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.CreateProcessorRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistent', full_name='yamcs.protobuf.processing.CreateProcessorRequest.persistent', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.processing.CreateProcessorRequest.type', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='yamcs.protobuf.processing.CreateProcessorRequest.config', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1763,
  serialized_end=1869,
)


_EDITPROCESSORREQUEST = _descriptor.Descriptor(
  name='EditProcessorRequest',
  full_name='yamcs.protobuf.processing.EditProcessorRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.EditProcessorRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.EditProcessorRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.processing.EditProcessorRequest.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seek', full_name='yamcs.protobuf.processing.EditProcessorRequest.seek', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.processing.EditProcessorRequest.speed', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.processing.EditProcessorRequest.start', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.processing.EditProcessorRequest.stop', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='loop', full_name='yamcs.protobuf.processing.EditProcessorRequest.loop', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1872,
  serialized_end=2102,
)


_GETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='GetParameterValueRequest',
  full_name='yamcs.protobuf.processing.GetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.GetParameterValueRequest.fromCache', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.GetParameterValueRequest.timeout', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2104,
  serialized_end=2217,
)


_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SetParameterValueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SetParameterValueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.SetParameterValueRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.SetParameterValueRequest.value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.processing.SetParameterValueRequest.generationTime', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiresIn', full_name='yamcs.protobuf.processing.SetParameterValueRequest.expiresIn', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2220,
  serialized_end=2406,
)


_BATCHGETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchGetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.instance', index=0,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.processor', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.id', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fromCache', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.fromCache', index=3,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='yamcs.protobuf.processing.BatchGetParameterValuesRequest.timeout', index=4,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2409,
  serialized_end=2557,
)


_BATCHGETPARAMETERVALUESRESPONSE = _descriptor.Descriptor(
  name='BatchGetParameterValuesResponse',
  full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchGetParameterValuesResponse.value', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2559,
  serialized_end=2646,
)


_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST = _descriptor.Descriptor(
  name='SetParameterValueRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='generationTime', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.generationTime', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiresIn', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest.expiresIn', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2822,
  serialized_end=3000,
)

_BATCHSETPARAMETERVALUESREQUEST = _descriptor.Descriptor(
  name='BatchSetParameterValuesRequest',
  full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.instance', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.processor', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.processing.BatchSetParameterValuesRequest.request', index=2,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2649,
  serialized_end=3000,
)


_GETALGORITHMSTATUSREQUEST = _descriptor.Descriptor(
  name='GetAlgorithmStatusRequest',
  full_name='yamcs.protobuf.processing.GetAlgorithmStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetAlgorithmStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetAlgorithmStatusRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetAlgorithmStatusRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3002,
  serialized_end=3080,
)


_SUBSCRIBEALGORITHMSTATUSREQUEST = _descriptor.Descriptor(
  name='SubscribeAlgorithmStatusRequest',
  full_name='yamcs.protobuf.processing.SubscribeAlgorithmStatusRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.SubscribeAlgorithmStatusRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.SubscribeAlgorithmStatusRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.SubscribeAlgorithmStatusRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3082,
  serialized_end=3166,
)


_GETALGORITHMTRACEREQUEST = _descriptor.Descriptor(
  name='GetAlgorithmTraceRequest',
  full_name='yamcs.protobuf.processing.GetAlgorithmTraceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.GetAlgorithmTraceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.GetAlgorithmTraceRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.GetAlgorithmTraceRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3168,
  serialized_end=3245,
)


_EDITALGORITHMTRACEREQUEST = _descriptor.Descriptor(
  name='EditAlgorithmTraceRequest',
  full_name='yamcs.protobuf.processing.EditAlgorithmTraceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.processing.EditAlgorithmTraceRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.processing.EditAlgorithmTraceRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.processing.EditAlgorithmTraceRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.processing.EditAlgorithmTraceRequest.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3247,
  serialized_end=3340,
)


_ALGORITHMSTATUS = _descriptor.Descriptor(
  name='AlgorithmStatus',
  full_name='yamcs.protobuf.processing.AlgorithmStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='yamcs.protobuf.processing.AlgorithmStatus.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traceEnabled', full_name='yamcs.protobuf.processing.AlgorithmStatus.traceEnabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runCount', full_name='yamcs.protobuf.processing.AlgorithmStatus.runCount', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lastRun', full_name='yamcs.protobuf.processing.AlgorithmStatus.lastRun', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorCount', full_name='yamcs.protobuf.processing.AlgorithmStatus.errorCount', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='yamcs.protobuf.processing.AlgorithmStatus.errorMessage', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorTime', full_name='yamcs.protobuf.processing.AlgorithmStatus.errorTime', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='execTimeNs', full_name='yamcs.protobuf.processing.AlgorithmStatus.execTimeNs', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3570,
)


_ALGORITHMTRACE_RUN = _descriptor.Descriptor(
  name='Run',
  full_name='yamcs.protobuf.processing.AlgorithmTrace.Run',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.processing.AlgorithmTrace.Run.time', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='yamcs.protobuf.processing.AlgorithmTrace.Run.inputs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputs', full_name='yamcs.protobuf.processing.AlgorithmTrace.Run.outputs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='returnValue', full_name='yamcs.protobuf.processing.AlgorithmTrace.Run.returnValue', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='yamcs.protobuf.processing.AlgorithmTrace.Run.error', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3714,
  serialized_end=3908,
)

_ALGORITHMTRACE_LOG = _descriptor.Descriptor(
  name='Log',
  full_name='yamcs.protobuf.processing.AlgorithmTrace.Log',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='yamcs.protobuf.processing.AlgorithmTrace.Log.time', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='yamcs.protobuf.processing.AlgorithmTrace.Log.msg', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3910,
  serialized_end=3970,
)

_ALGORITHMTRACE = _descriptor.Descriptor(
  name='AlgorithmTrace',
  full_name='yamcs.protobuf.processing.AlgorithmTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='runs', full_name='yamcs.protobuf.processing.AlgorithmTrace.runs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logs', full_name='yamcs.protobuf.processing.AlgorithmTrace.logs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ALGORITHMTRACE_RUN, _ALGORITHMTRACE_LOG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3573,
  serialized_end=3970,
)

_LISTPROCESSORSRESPONSE.fields_by_name['processors'].message_type = yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO
_SUBSCRIBEPARAMETERSREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_SUBSCRIBEPARAMETERSREQUEST.fields_by_name['action'].enum_type = _SUBSCRIBEPARAMETERSREQUEST_ACTION
_SUBSCRIBEPARAMETERSREQUEST_ACTION.containing_type = _SUBSCRIBEPARAMETERSREQUEST
_SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY.containing_type = _SUBSCRIBEPARAMETERSDATA
_SUBSCRIBEPARAMETERSDATA_INFOENTRY.fields_by_name['value'].message_type = _SUBSCRIBEDPARAMETERINFO
_SUBSCRIBEPARAMETERSDATA_INFOENTRY.containing_type = _SUBSCRIBEPARAMETERSDATA
_SUBSCRIBEPARAMETERSDATA.fields_by_name['mapping'].message_type = _SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY
_SUBSCRIBEPARAMETERSDATA.fields_by_name['info'].message_type = _SUBSCRIBEPARAMETERSDATA_INFOENTRY
_SUBSCRIBEPARAMETERSDATA.fields_by_name['invalid'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_SUBSCRIBEPARAMETERSDATA.fields_by_name['values'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_SUBSCRIBEDPARAMETERINFO.fields_by_name['dataSource'].enum_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._DATASOURCETYPE
_SUBSCRIBEDPARAMETERINFO.fields_by_name['enumValues'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._ENUMVALUE
_SUBSCRIBEDPARAMETERINFO.fields_by_name['enumRanges'].message_type = yamcs_dot_protobuf_dot_mdb_dot_mdb__pb2._ENUMRANGE
_EDITPROCESSORREQUEST.fields_by_name['seek'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EDITPROCESSORREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_EDITPROCESSORREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_SETPARAMETERVALUEREQUEST.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHGETPARAMETERVALUESREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHGETPARAMETERVALUESRESPONSE.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['id'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._NAMEDOBJECTID
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.fields_by_name['generationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST.containing_type = _BATCHSETPARAMETERVALUESREQUEST
_BATCHSETPARAMETERVALUESREQUEST.fields_by_name['request'].message_type = _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST
_ALGORITHMSTATUS.fields_by_name['lastRun'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALGORITHMSTATUS.fields_by_name['errorTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALGORITHMTRACE_RUN.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALGORITHMTRACE_RUN.fields_by_name['inputs'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_ALGORITHMTRACE_RUN.fields_by_name['outputs'].message_type = yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE
_ALGORITHMTRACE_RUN.containing_type = _ALGORITHMTRACE
_ALGORITHMTRACE_LOG.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ALGORITHMTRACE_LOG.containing_type = _ALGORITHMTRACE
_ALGORITHMTRACE.fields_by_name['runs'].message_type = _ALGORITHMTRACE_RUN
_ALGORITHMTRACE.fields_by_name['logs'].message_type = _ALGORITHMTRACE_LOG
DESCRIPTOR.message_types_by_name['ListProcessorTypesResponse'] = _LISTPROCESSORTYPESRESPONSE
DESCRIPTOR.message_types_by_name['ListProcessorsRequest'] = _LISTPROCESSORSREQUEST
DESCRIPTOR.message_types_by_name['ListProcessorsResponse'] = _LISTPROCESSORSRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeTMStatisticsRequest'] = _SUBSCRIBETMSTATISTICSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeProcessorsRequest'] = _SUBSCRIBEPROCESSORSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeParametersRequest'] = _SUBSCRIBEPARAMETERSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeParametersData'] = _SUBSCRIBEPARAMETERSDATA
DESCRIPTOR.message_types_by_name['SubscribedParameterInfo'] = _SUBSCRIBEDPARAMETERINFO
DESCRIPTOR.message_types_by_name['GetProcessorRequest'] = _GETPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['DeleteProcessorRequest'] = _DELETEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['CreateProcessorRequest'] = _CREATEPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['EditProcessorRequest'] = _EDITPROCESSORREQUEST
DESCRIPTOR.message_types_by_name['GetParameterValueRequest'] = _GETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['SetParameterValueRequest'] = _SETPARAMETERVALUEREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesRequest'] = _BATCHGETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['BatchGetParameterValuesResponse'] = _BATCHGETPARAMETERVALUESRESPONSE
DESCRIPTOR.message_types_by_name['BatchSetParameterValuesRequest'] = _BATCHSETPARAMETERVALUESREQUEST
DESCRIPTOR.message_types_by_name['GetAlgorithmStatusRequest'] = _GETALGORITHMSTATUSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeAlgorithmStatusRequest'] = _SUBSCRIBEALGORITHMSTATUSREQUEST
DESCRIPTOR.message_types_by_name['GetAlgorithmTraceRequest'] = _GETALGORITHMTRACEREQUEST
DESCRIPTOR.message_types_by_name['EditAlgorithmTraceRequest'] = _EDITALGORITHMTRACEREQUEST
DESCRIPTOR.message_types_by_name['AlgorithmStatus'] = _ALGORITHMSTATUS
DESCRIPTOR.message_types_by_name['AlgorithmTrace'] = _ALGORITHMTRACE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListProcessorTypesResponse = _reflection.GeneratedProtocolMessageType('ListProcessorTypesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORTYPESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorTypesResponse)
  })
_sym_db.RegisterMessage(ListProcessorTypesResponse)

ListProcessorsRequest = _reflection.GeneratedProtocolMessageType('ListProcessorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorsRequest)
  })
_sym_db.RegisterMessage(ListProcessorsRequest)

ListProcessorsResponse = _reflection.GeneratedProtocolMessageType('ListProcessorsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTPROCESSORSRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.ListProcessorsResponse)
  })
_sym_db.RegisterMessage(ListProcessorsResponse)

SubscribeTMStatisticsRequest = _reflection.GeneratedProtocolMessageType('SubscribeTMStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBETMSTATISTICSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeTMStatisticsRequest)
  })
_sym_db.RegisterMessage(SubscribeTMStatisticsRequest)

SubscribeProcessorsRequest = _reflection.GeneratedProtocolMessageType('SubscribeProcessorsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEPROCESSORSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeProcessorsRequest)
  })
_sym_db.RegisterMessage(SubscribeProcessorsRequest)

SubscribeParametersRequest = _reflection.GeneratedProtocolMessageType('SubscribeParametersRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEPARAMETERSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeParametersRequest)
  })
_sym_db.RegisterMessage(SubscribeParametersRequest)

SubscribeParametersData = _reflection.GeneratedProtocolMessageType('SubscribeParametersData', (_message.Message,), {

  'MappingEntry' : _reflection.GeneratedProtocolMessageType('MappingEntry', (_message.Message,), {
    'DESCRIPTOR' : _SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeParametersData.MappingEntry)
    })
  ,

  'InfoEntry' : _reflection.GeneratedProtocolMessageType('InfoEntry', (_message.Message,), {
    'DESCRIPTOR' : _SUBSCRIBEPARAMETERSDATA_INFOENTRY,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeParametersData.InfoEntry)
    })
  ,
  'DESCRIPTOR' : _SUBSCRIBEPARAMETERSDATA,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeParametersData)
  })
_sym_db.RegisterMessage(SubscribeParametersData)
_sym_db.RegisterMessage(SubscribeParametersData.MappingEntry)
_sym_db.RegisterMessage(SubscribeParametersData.InfoEntry)

SubscribedParameterInfo = _reflection.GeneratedProtocolMessageType('SubscribedParameterInfo', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEDPARAMETERINFO,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribedParameterInfo)
  })
_sym_db.RegisterMessage(SubscribedParameterInfo)

GetProcessorRequest = _reflection.GeneratedProtocolMessageType('GetProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetProcessorRequest)
  })
_sym_db.RegisterMessage(GetProcessorRequest)

DeleteProcessorRequest = _reflection.GeneratedProtocolMessageType('DeleteProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.DeleteProcessorRequest)
  })
_sym_db.RegisterMessage(DeleteProcessorRequest)

CreateProcessorRequest = _reflection.GeneratedProtocolMessageType('CreateProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.CreateProcessorRequest)
  })
_sym_db.RegisterMessage(CreateProcessorRequest)

EditProcessorRequest = _reflection.GeneratedProtocolMessageType('EditProcessorRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITPROCESSORREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.EditProcessorRequest)
  })
_sym_db.RegisterMessage(EditProcessorRequest)

GetParameterValueRequest = _reflection.GeneratedProtocolMessageType('GetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetParameterValueRequest)
  })
_sym_db.RegisterMessage(GetParameterValueRequest)

SetParameterValueRequest = _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETPARAMETERVALUEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SetParameterValueRequest)
  })
_sym_db.RegisterMessage(SetParameterValueRequest)

BatchGetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesRequest', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesRequest)

BatchGetParameterValuesResponse = _reflection.GeneratedProtocolMessageType('BatchGetParameterValuesResponse', (_message.Message,), {
  'DESCRIPTOR' : _BATCHGETPARAMETERVALUESRESPONSE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchGetParameterValuesResponse)
  })
_sym_db.RegisterMessage(BatchGetParameterValuesResponse)

BatchSetParameterValuesRequest = _reflection.GeneratedProtocolMessageType('BatchSetParameterValuesRequest', (_message.Message,), {

  'SetParameterValueRequest' : _reflection.GeneratedProtocolMessageType('SetParameterValueRequest', (_message.Message,), {
    'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST_SETPARAMETERVALUEREQUEST,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest.SetParameterValueRequest)
    })
  ,
  'DESCRIPTOR' : _BATCHSETPARAMETERVALUESREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.BatchSetParameterValuesRequest)
  })
_sym_db.RegisterMessage(BatchSetParameterValuesRequest)
_sym_db.RegisterMessage(BatchSetParameterValuesRequest.SetParameterValueRequest)

GetAlgorithmStatusRequest = _reflection.GeneratedProtocolMessageType('GetAlgorithmStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetAlgorithmStatusRequest)
  })
_sym_db.RegisterMessage(GetAlgorithmStatusRequest)

SubscribeAlgorithmStatusRequest = _reflection.GeneratedProtocolMessageType('SubscribeAlgorithmStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBSCRIBEALGORITHMSTATUSREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.SubscribeAlgorithmStatusRequest)
  })
_sym_db.RegisterMessage(SubscribeAlgorithmStatusRequest)

GetAlgorithmTraceRequest = _reflection.GeneratedProtocolMessageType('GetAlgorithmTraceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALGORITHMTRACEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.GetAlgorithmTraceRequest)
  })
_sym_db.RegisterMessage(GetAlgorithmTraceRequest)

EditAlgorithmTraceRequest = _reflection.GeneratedProtocolMessageType('EditAlgorithmTraceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EDITALGORITHMTRACEREQUEST,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.EditAlgorithmTraceRequest)
  })
_sym_db.RegisterMessage(EditAlgorithmTraceRequest)

AlgorithmStatus = _reflection.GeneratedProtocolMessageType('AlgorithmStatus', (_message.Message,), {
  'DESCRIPTOR' : _ALGORITHMSTATUS,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.AlgorithmStatus)
  })
_sym_db.RegisterMessage(AlgorithmStatus)

AlgorithmTrace = _reflection.GeneratedProtocolMessageType('AlgorithmTrace', (_message.Message,), {

  'Run' : _reflection.GeneratedProtocolMessageType('Run', (_message.Message,), {
    'DESCRIPTOR' : _ALGORITHMTRACE_RUN,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.AlgorithmTrace.Run)
    })
  ,

  'Log' : _reflection.GeneratedProtocolMessageType('Log', (_message.Message,), {
    'DESCRIPTOR' : _ALGORITHMTRACE_LOG,
    '__module__' : 'yamcs.protobuf.processing.processing_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.AlgorithmTrace.Log)
    })
  ,
  'DESCRIPTOR' : _ALGORITHMTRACE,
  '__module__' : 'yamcs.protobuf.processing.processing_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.processing.AlgorithmTrace)
  })
_sym_db.RegisterMessage(AlgorithmTrace)
_sym_db.RegisterMessage(AlgorithmTrace.Run)
_sym_db.RegisterMessage(AlgorithmTrace.Log)


DESCRIPTOR._options = None
_SUBSCRIBEPARAMETERSDATA_MAPPINGENTRY._options = None
_SUBSCRIBEPARAMETERSDATA_INFOENTRY._options = None

_PROCESSINGAPI = _descriptor.ServiceDescriptor(
  name='ProcessingApi',
  full_name='yamcs.protobuf.processing.ProcessingApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\320\200\001\001',
  serialized_start=3973,
  serialized_end=6800,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListProcessorTypes',
    full_name='yamcs.protobuf.processing.ProcessingApi.ListProcessorTypes',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTPROCESSORTYPESRESPONSE,
    serialized_options=b'\212\222\003\026\n\024/api/processor-types',
  ),
  _descriptor.MethodDescriptor(
    name='ListProcessors',
    full_name='yamcs.protobuf.processing.ProcessingApi.ListProcessors',
    index=1,
    containing_service=None,
    input_type=_LISTPROCESSORSREQUEST,
    output_type=_LISTPROCESSORSRESPONSE,
    serialized_options=b'\212\222\003\021\n\017/api/processors',
  ),
  _descriptor.MethodDescriptor(
    name='GetProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetProcessor',
    index=2,
    containing_service=None,
    input_type=_GETPROCESSORREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO,
    serialized_options=b'\212\222\003(\n&/api/processors/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='DeleteProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.DeleteProcessor',
    index=3,
    containing_service=None,
    input_type=_DELETEPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003(\"&/api/processors/{instance}/{processor}',
  ),
  _descriptor.MethodDescriptor(
    name='EditProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.EditProcessor',
    index=4,
    containing_service=None,
    input_type=_EDITPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003+*&/api/processors/{instance}/{processor}:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='CreateProcessor',
    full_name='yamcs.protobuf.processing.ProcessingApi.CreateProcessor',
    index=5,
    containing_service=None,
    input_type=_CREATEPROCESSORREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\024\032\017/api/processors:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='GetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetParameterValue',
    index=6,
    containing_service=None,
    input_type=_GETPARAMETERVALUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_pvalue_dot_pvalue__pb2._PARAMETERVALUE,
    serialized_options=b'\212\222\003;\n9/api/processors/{instance}/{processor}/parameters/{name*}',
  ),
  _descriptor.MethodDescriptor(
    name='SetParameterValue',
    full_name='yamcs.protobuf.processing.ProcessingApi.SetParameterValue',
    index=7,
    containing_service=None,
    input_type=_SETPARAMETERVALUEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003\206\001\0229/api/processors/{instance}/{processor}/parameters/{name*}:\005valueZB\0329/api/processors/{instance}/{processor}/parameters/{name*}:\005value',
  ),
  _descriptor.MethodDescriptor(
    name='BatchGetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchGetParameterValues',
    index=8,
    containing_service=None,
    input_type=_BATCHGETPARAMETERVALUESREQUEST,
    output_type=_BATCHGETPARAMETERVALUESRESPONSE,
    serialized_options=b'\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchGet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='BatchSetParameterValues',
    full_name='yamcs.protobuf.processing.ProcessingApi.BatchSetParameterValues',
    index=9,
    containing_service=None,
    input_type=_BATCHSETPARAMETERVALUESREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003?\032:/api/processors/{instance}/{processor}/parameters:batchSet:\001*',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeTMStatistics',
    full_name='yamcs.protobuf.processing.ProcessingApi.SubscribeTMStatistics',
    index=10,
    containing_service=None,
    input_type=_SUBSCRIBETMSTATISTICSREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._STATISTICS,
    serialized_options=b'\332\222\003\t\n\007tmstats',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeParameters',
    full_name='yamcs.protobuf.processing.ProcessingApi.SubscribeParameters',
    index=11,
    containing_service=None,
    input_type=_SUBSCRIBEPARAMETERSREQUEST,
    output_type=_SUBSCRIBEPARAMETERSDATA,
    serialized_options=b'\332\222\003\014\n\nparameters',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeProcessors',
    full_name='yamcs.protobuf.processing.ProcessingApi.SubscribeProcessors',
    index=12,
    containing_service=None,
    input_type=_SUBSCRIBEPROCESSORSREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._PROCESSORINFO,
    serialized_options=b'\332\222\003\014\n\nprocessors',
  ),
  _descriptor.MethodDescriptor(
    name='GetAlgorithmStatus',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetAlgorithmStatus',
    index=13,
    containing_service=None,
    input_type=_GETALGORITHMSTATUSREQUEST,
    output_type=_ALGORITHMSTATUS,
    serialized_options=b'\212\222\003B\n@/api/processors/{instance}/{processor}/algorithms/{name*}/status',
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeAlgorithmStatus',
    full_name='yamcs.protobuf.processing.ProcessingApi.SubscribeAlgorithmStatus',
    index=14,
    containing_service=None,
    input_type=_SUBSCRIBEALGORITHMSTATUSREQUEST,
    output_type=_ALGORITHMSTATUS,
    serialized_options=b'\332\222\003\022\n\020algorithm-status',
  ),
  _descriptor.MethodDescriptor(
    name='GetAlgorithmTrace',
    full_name='yamcs.protobuf.processing.ProcessingApi.GetAlgorithmTrace',
    index=15,
    containing_service=None,
    input_type=_GETALGORITHMTRACEREQUEST,
    output_type=_ALGORITHMTRACE,
    serialized_options=b'\212\222\003A\n?/api/processors/{instance}/{processor}/algorithms/{name*}/trace',
  ),
  _descriptor.MethodDescriptor(
    name='EditAlgorithmTrace',
    full_name='yamcs.protobuf.processing.ProcessingApi.EditAlgorithmTrace',
    index=16,
    containing_service=None,
    input_type=_EDITALGORITHMTRACEREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=b'\212\222\003D*?/api/processors/{instance}/{processor}/algorithms/{name*}/trace:\001*',
  ),
])
_sym_db.RegisterServiceDescriptor(_PROCESSINGAPI)

DESCRIPTOR.services_by_name['ProcessingApi'] = _PROCESSINGAPI

# @@protoc_insertion_point(module_scope)



import logging
import ssl
import threading

import websocket
from yamcs.api import websocket_pb2
from yamcs.client.core.context import Context
from yamcs.client.core.exceptions import ConnectionFailure

__all__ = [
    "WebSocketSubscriptionManager",
]

logger = logging.getLogger("yamcs-client")


class WebSocketSubscriptionManager:
    def __init__(self, ctx: Context, topic: str, options=None):
        self.ctx = ctx
        self._topic = topic
        self._options = options

        self._websocket = None
        self._callback = None
        self._response_callbacks = []
        self._close_callbacks = []

        self._closing = threading.Lock()
        self._closed = False
        """True if this manager has already been closed."""

        self._request_counter = 0
        self._request_counter_lock = threading.Lock()
        self._call = None
        self._call_assigned = threading.Event()

        # Thread created in ``.open()``
        self._consumer = None

    def add_response_callback(self, callback):
        """
        Schedules a callable when a response was received.
        """
        self._response_callbacks.append(callback)

    def add_close_callback(self, callback):
        """
        Schedules a callable when the manager closes.
        """
        self._close_callbacks.append(callback)

    def open(self, callback):
        """
        Begin consuming messages.
        """
        assert not self._closed

        if self.ctx.credentials:
            self.ctx.credentials.before_request(self.ctx.session, self.ctx.auth_root)

        self._callback = callback
        self._websocket = websocket.WebSocketApp(
            self.ctx.ws_root,
            on_open=self._on_websocket_open,
            on_message=self._on_websocket_message,
            on_error=self._on_websocket_error,
            subprotocols=["protobuf"],
            header=[
                f"{k}: {self.ctx.session.headers[k]}" for k in self.ctx.session.headers
            ],
        )

        kwargs = {}
        if self.ctx.session.verify is False:
            kwargs["sslopt"] = {"cert_reqs": ssl.CERT_NONE}
        elif self.ctx.session.verify is not True:
            kwargs["sslopt"] = {"ca_certs": self.ctx.session.verify}

        self._consumer = threading.Thread(
            target=self._websocket.run_forever, kwargs=kwargs
        )

        # Running this as a daemon thread improves possibilities for consumers
        # of our API to control shutdown. For example can can just use
        # time.sleep on the main thread instead of blocking on the future.
        self._consumer.daemon = True

        self._consumer.start()

    def close(self, reason=None):
        """
        Stop consuming messages and perform an orderly shutdown.

        If ``reason`` is None, then this is considered a regular close.
        """
        with self._closing:
            if self._closed:
                return

            assert self._websocket is not None
            assert self._consumer is not None

            self._websocket.close()

            self._consumer.join()
            self._consumer = None

            self._websocket = None
            self._closed = True
            for cb in self._close_callbacks:
                cb(self, reason)

    def send(self, options=None):
        message = websocket_pb2.ClientMessage()
        message.type = self._topic

        # Ensure the server has already replied to the
        # previous message. (we want to be sure we know
        # our server-assigned call already)
        if self._request_counter > 0:
            if self._call is None:
                self._call_assigned.wait()
                assert self._call is not None
            message.call = self._call

        message.id = self._next_sequence_number()
        if options:
            getattr(message, "options").Pack(options)

        frame_data = message.SerializeToString()

        assert self._websocket is not None
        self._websocket.send(frame_data, websocket.ABNF.OPCODE_BINARY)

    def _on_websocket_open(self, ws=None):
        # WebSocketApp ``on_open`` callbacks had a temporary signature
        # change between websocket-client 0.48.0..0.57.0, hence we make
        # the ``ws`` argument optional.
        # https://github.com/websocket-client/websocket-client/issues/669
        #
        # This workaround can be dropped once we force websocket-client
        # to be >0.57
        self.send(self._options)

    def _on_websocket_message(self, ws, message=None):
        # WebSocketApp ``on_message`` callbacks had a temporary signature
        # change between websocket-client 0.48.0..0.57.0.
        # https://github.com/websocket-client/websocket-client/issues/669
        #
        # This workaround can be dropped once we force websocket-client
        # to be >0.57
        if message is None:
            message = ws

        try:
            pb2_message = websocket_pb2.ServerMessage()
            pb2_message.ParseFromString(message)

            type_ = getattr(pb2_message, "type")
            if type_ == "reply":
                reply = websocket_pb2.Reply()
                getattr(pb2_message, "data").Unpack(reply)
                if reply.HasField("exception"):
                    for cb in self._response_callbacks:
                        cb(self, exception=getattr(reply, "exception"))
                else:
                    if self._call is None:
                        self._call = getattr(pb2_message, "call")
                        self._call_assigned.set()
                    for cb in self._response_callbacks:
                        cb(self)
            else:
                data = getattr(pb2_message, "data")

                assert self._callback is not None
                self._callback(data)
        except Exception as e:
            logger.exception("Problem while processing message. Closing connection")
            self._close_async(reason=e)

    def _on_websocket_error(self, ws, error=None):
        # WebSocketApp ``on_error`` callbacks had a temporary signature
        # change between websocket-client 0.48.0..0.57.0.
        # https://github.com/websocket-client/websocket-client/issues/669
        #
        # This workaround can be dropped once we force websocket-client
        # to be >0.57
        if error is None:
            error = ws

        # Set to False to avoid printing some errors twice
        # (the ones that are generated during an initial connection)
        log_error = True

        # Generate custom exception.
        # (the default message is misleading 'connection is already closed')
        if isinstance(error, websocket.WebSocketConnectionClosedException):
            error = ConnectionFailure("Connection closed")
        elif isinstance(error, websocket.WebSocketAddressException):
            # No log because this error usually happens while blocking on an
            # initial connection, so prefer not to print it twice.
            log_error = False
            msg = f"Connection to {self.ctx.url} failed: could not resolve hostname"
            error = ConnectionFailure(msg)
        elif isinstance(error, ConnectionRefusedError):
            log_error = False
            msg = f"Connection to {self.ctx.url} failed: connection refused"
            error = ConnectionFailure(msg)

        if log_error:
            logger.error("WebSocket error: %s", error)

        self._close_async(reason=error)

    def _close_async(self, reason):
        # Close async. This is to not get stuck in the above ``join()``.
        closer = threading.Thread(target=self.close, kwargs={"reason": reason})
        closer.daemon = True
        closer.start()

    def _next_sequence_number(self):
        with self._request_counter_lock:
            self._request_counter += 1
            return self._request_counter
